@@ -81,11 +81,9 @@ function PMA_getHtmlForRenameDatabase($db)
         . 'value="' . htmlspecialchars($db) . '"/>';
 
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['db_priv']) && $GLOBALS['db_priv']
-            && isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['proc_priv']) && $GLOBALS['proc_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['db_priv'] && $GLOBALS['table_priv']
+            && $GLOBALS['col_priv'] && $GLOBALS['proc_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $html_output .= '<input type="checkbox" name="adjust_privileges" '
                 . 'value="1" id="checkbox_adjust_privileges" checked="checked" />';
@@ -229,11 +227,9 @@ function PMA_getHtmlForCopyDatabase($db)
     $html_output .= '<br />';
 
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['db_priv']) && $GLOBALS['db_priv']
-            && isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['proc_priv']) && $GLOBALS['proc_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['db_priv'] && $GLOBALS['table_priv']
+            && $GLOBALS['col_priv'] && $GLOBALS['proc_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $html_output .= '<input type="checkbox" name="adjust_privileges" '
                 . 'value="1" id="checkbox_privileges" checked="checked" />';
@@ -587,13 +583,13 @@ function PMA_handleTheViews($views, $move, $db)
 function PMA_AdjustPrivileges_moveDB($oldDb, $newname)
 {
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['db_priv']) && $GLOBALS['db_priv']
-            && isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['proc_priv']) && $GLOBALS['proc_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['db_priv'] && $GLOBALS['table_priv']
+            && $GLOBALS['col_priv'] && $GLOBALS['proc_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $GLOBALS['dbi']->selectDb('mysql');
+            $newname = str_replace("_", "\_", $newname);
+            $oldDb = str_replace("_", "\_", $oldDb);
 
             // For Db specific privileges
             $query_db_specific = 'UPDATE ' . PMA_Util::backquote('db')
@@ -637,13 +633,13 @@ function PMA_AdjustPrivileges_moveDB($oldDb, $newname)
 function PMA_AdjustPrivileges_copyDB($oldDb, $newname)
 {
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['db_priv']) && $GLOBALS['db_priv']
-            && isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['proc_priv']) && $GLOBALS['proc_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['db_priv'] && $GLOBALS['table_priv']
+            && $GLOBALS['col_priv'] && $GLOBALS['proc_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $GLOBALS['dbi']->selectDb('mysql');
+            $newname = str_replace("_", "\_", $newname);
+            $oldDb = str_replace("_", "\_", $oldDb);
 
             $query_db_specific_old = 'SELECT * FROM '
                 . PMA_Util::backquote('db') . ' WHERE '
@@ -860,9 +856,8 @@ function PMA_getHtmlForMoveTable()
         . '</label><br />';
 
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['table_priv'] && $GLOBALS['col_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $html_output .= '<input type="checkbox" name="adjust_privileges" '
                 . 'value="1" id="checkbox_privileges_tables_move" '
@@ -954,9 +949,8 @@ function PMA_getHtmlForRenameTable()
         . '<tr><td></td><td>';
 
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['table_priv'] && $GLOBALS['col_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $html_output .= '<input type="checkbox" name="adjust_privileges" '
                 . 'value="1" id="checkbox_privileges_table_options" '
@@ -1309,9 +1303,8 @@ function PMA_getHtmlForCopytable()
     $html_output .= '<br />';
 
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['table_priv'] && $GLOBALS['col_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $html_output .= '<input type="checkbox" name="adjust_privileges" '
                 . 'value="1" id="checkbox_adjust_privileges" checked="checked" />';
@@ -1879,7 +1872,7 @@ function PMA_getTableAltersArray($is_myisam_or_aria, $is_isam, $pack_keys,
  */
 function PMA_setGlobalVariablesForEngine($tbl_storage_engine)
 {
-    $upperTblStorEngine = /*overload*/mb_strtoupper($tbl_storage_engine);
+    $upperTblStorEngine = $tbl_storage_engine;
 
     //Options that apply to MYISAM usually apply to ARIA
     $is_myisam_or_aria = ($upperTblStorEngine == 'MYISAM'
@@ -1962,9 +1955,8 @@ function PMA_getQueryAndResultForPartition()
 function PMA_AdjustPrivileges_renameOrMoveTable($oldDb, $oldTable, $newDb, $newTable)
 {
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['table_priv'] && $GLOBALS['col_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $GLOBALS['dbi']->selectDb('mysql');
 
@@ -2002,9 +1994,8 @@ function PMA_AdjustPrivileges_renameOrMoveTable($oldDb, $oldTable, $newDb, $newT
 function PMA_AdjustPrivileges_copyTable($oldDb, $oldTable, $newDb, $newTable)
 {
     if (! PMA_DRIZZLE) {
-        if (isset($GLOBALS['table_priv']) && $GLOBALS['table_priv']
-            && isset($GLOBALS['col_priv']) && $GLOBALS['col_priv']
-            && isset($GLOBALS['flush_priv']) && $GLOBALS['flush_priv']
+        if ($GLOBALS['table_priv'] && $GLOBALS['col_priv']
+            && $GLOBALS['is_reload_priv']
         ) {
             $GLOBALS['dbi']->selectDb('mysql');
 
